<?php

if ( ! function_exists( 'joinup_include_comments_in_templates' ) ) {
	/**
	 * Function which includes comments templates on pages/posts
	 */
	function joinup_include_comments_in_templates() {

		// Include comments template
		comments_template();
	}

	add_action( 'joinup_action_after_page_content', 'joinup_include_comments_in_templates', 100 ); // permission 100 is set to comments template be at the last place
	add_action( 'joinup_action_after_blog_post_item', 'joinup_include_comments_in_templates', 100 );
}

if ( ! function_exists( 'joinup_is_page_comments_enabled' ) ) {
	/**
	 * Function that check is module enabled
	 */
	function joinup_is_page_comments_enabled() {
		$is_enabled = apply_filters( 'joinup_filter_enable_page_comments', true );

		return $is_enabled;
	}
}

if ( ! function_exists( 'joinup_load_page_comments' ) ) {
	/**
	 * Function which loads page template module
	 */
	function joinup_load_page_comments() {

		if ( joinup_is_page_comments_enabled() ) {
			joinup_template_part( 'comments', 'templates/comments' );
		}
	}

	add_action( 'joinup_action_page_comments_template', 'joinup_load_page_comments' );
}

if ( ! function_exists( 'joinup_get_comments_list_template' ) ) {
	/**
	 * Function which modify default wordpress comments list template
	 *
	 * @param object $comment
	 * @param array $args
	 * @param int $depth
	 *
	 * @return string that contains comments list html
	 */
	function joinup_get_comments_list_template( $comment, $args, $depth ) {
		global $post;
		$GLOBALS['comment'] = $comment;

		$classes = array();

		$is_author_comment = $post->post_author == $comment->user_id;
		if ( $is_author_comment ) {
			$classes[] = 'qodef-comment--author';
		}

		$is_specific_comment = $comment->comment_type == 'pingback' || $comment->comment_type == 'trackback';
		if ( $is_specific_comment ) {
			$classes[] = 'qodef-comment--no-avatar';
			$classes[] = 'qodef-comment--' . esc_attr( $comment->comment_type );
		}
		?>
    <li class="qodef-comment-item qodef-e <?php echo esc_attr( implode( ' ', $classes ) ); ?>">
        <div id="comment-<?php comment_ID(); ?>" class="qodef-e-inner">
			<?php if ( ! $is_specific_comment ) { ?>
                <div class="qodef-e-image"><?php echo get_avatar( $comment, 80 ); ?></div>
			<?php } ?>
            <div class="qodef-e-content">
                <div class="qodef-comment-trialngle-holder">
                    <div class="qodef-comment-triangle qodef-comment-triangle-left qodef-comment-triangle-border"></div>
                </div>
                <h5 class="qodef-e-title vcard"><?php echo sprintf( '<span class="fn">%s%s</span>', $is_specific_comment ? sprintf( '%s: ', esc_attr( ucwords( $comment->comment_type ) ) ) : '', get_comment_author_link() ); ?></h5>
                <div class="qodef-e-date commentmetadata">
                    <span class="qodef-e-date-label"><?php echo esc_html__( 'said on ', 'joinup' ); ?></span><a href="<?php echo esc_url( get_comment_link( $comment, $args ) ); ?>"><?php comment_time( get_option( 'date_format' ) ); ?></a>
                </div>
				<?php if ( ! $is_specific_comment ) { ?>
                    <p class="qodef-e-text"><?php echo get_comment_text( $comment ); ?></p>
				<?php } ?>
                <div class="qodef-e-links">
					<?php

                    $reply_icon = '';
                    if (joinup_is_installed( 'core' )) {
                        $reply_icon = joinup_get_icon('kiko-comment kikol', 'kiko', '');
                    } else {
                        $reply_icon = '<svg xmlns="http://www.w3.org/2000/svg" width="32" height="32" viewBox="0 0 32 32"><g><g data-name="Regular"><path d="M7.5,32A1.5,1.5,0,0,1,6,30.5V25H1.5A1.5,1.5,0,0,1,0,23.5V3.5A1.5,1.5,0,0,1,1.5,2h29A1.5,1.5,0,0,1,32,3.5v20A1.5,1.5,0,0,1,30.5,25H15.121l-6.56,6.561A1.5,1.5,0,0,1,7.5,32ZM3,22H7.5A1.5,1.5,0,0,1,9,23.5v3.379l4.439-4.44A1.5,1.5,0,0,1,14.5,22H29V5H3Zm17-5.5A1.5,1.5,0,0,0,18.5,15H8.5a1.5,1.5,0,0,0,0,3h10A1.5,1.5,0,0,0,20,16.5Zm5-6A1.5,1.5,0,0,0,23.5,9H8.5a1.5,1.5,0,0,0,0,3h15A1.5,1.5,0,0,0,25,10.5Z"/></g></g></svg>';
                    }

					comment_reply_link( array_merge( $args, array(
						'reply_text' => $reply_icon . esc_html__( 'Reply', 'joinup' ),
						'depth'      => $depth,
						'max_depth'  => $args['max_depth'],
					) ) );

                    $edit_icon = '';
                    if (joinup_is_installed( 'core' )) {
                        $edit_icon = joinup_get_icon('kiko-pencil kikol', 'kiko', '');
                    } else {
                        $edit_icon = '<svg xmlns="http://www.w3.org/2000/svg" width="32" height="32" viewBox="0 0 32 32"><g><g data-name="Regular"><path d="M30.854,4.555,27.445,1.146a3.911,3.911,0,0,0-5.529,0L19.15,3.911A1.487,1.487,0,0,0,17.182,5.88l-2.8,2.8a1.487,1.487,0,0,0-1.969,1.968L.439,22.622A1.5,1.5,0,0,0,0,23.683V30.5A1.5,1.5,0,0,0,1.5,32H8.317a1.5,1.5,0,0,0,1.061-.439l11.97-11.97a1.487,1.487,0,0,0,1.968-1.969l2.8-2.8a1.487,1.487,0,0,0,1.969-1.968l2.765-2.766A3.913,3.913,0,0,0,30.854,4.555ZM19.227,8.077l4.7,4.7-2.652,2.652-4.7-4.7ZM7.7,29h-2.3L3,26.607V24.3L14.454,12.85l4.7,4.7ZM28.733,7.963l-2.689,2.689-4.7-4.7,2.689-2.689a.909.909,0,0,1,1.287,0l3.409,3.409A.911.911,0,0,1,28.733,7.963Z"/></g></g></svg>';
                    }

					edit_comment_link( $edit_icon . esc_html__( 'Edit', 'joinup' ) ); ?>
                </div>
            </div>
        </div>
		<?php //li tag will be closed by WordPress after looping through child elements ?>
		<?php
	}
}

if ( ! function_exists( 'joinup_get_comment_form_args' ) ) {
    /**
     * Function that define new comment form args in order to override default wordpress comment form
     *
     * @param array $attr - additional array which override default values
     *
     * @return array
     */
    function joinup_get_comment_form_args( $attr = array()) {
	    $qodef_commenter      = wp_get_current_commenter();
	    $qodef_required_attr  = get_option( 'require_name_email' ) ? ' required="required"' : '';
	    $qodef_required_label = get_option( 'require_name_email' ) ? '*' : '';
	    
	    $comment_placeholder = isset( $attr['comment_placeholder'] ) && ! empty( $attr['comment_placeholder'] ) ? esc_attr( $attr['comment_placeholder'] ) : esc_attr__( 'Write a comment...', 'joinup' );
	
	    $args = array(
		    'title_reply_before' => '<h4 id="reply-title" class="comment-reply-title">',
		    'title_reply_after'  => '</h4>',
		    'comment_field'      => '<label for="comment" class="qodef-comment-form-label">' .esc_html__('Comment', 'joinup'). '<span>*</span></label>
                                    <div class="qodef-input-holder">
                                    <textarea id="comment" name="comment" placeholder="' . $comment_placeholder . '" cols="45" rows="8" maxlength="65525" required="required"></textarea>
                                    <span class="qodef-icon kikol kiko-pencil"></span></div>',
		    'fields'             => array(
			    'author' => '<label for="author" class="qodef-comment-form-label">' .esc_html__('Name', 'joinup'). '<span>*</span></label>
                            <div class="qodef-input-holder">
                            <input id="author" name="author" placeholder="' .  esc_attr__( 'Your Name', 'joinup') . '" type="text" value="' . esc_attr( $qodef_commenter['comment_author'] ) . '" size="30" maxlength="245" ' . $qodef_required_attr . ' />
                            <span class="qodef-icon kikol kiko-user"></span></div>',
			    'email'  => '<label for="email" class="qodef-comment-form-label">' .esc_html__('Email', 'joinup'). '<span>*</span></label>
                            <div class="qodef-input-holder">
                            <input id="email" name="email" placeholder="' .  esc_attr__( 'Your Email', 'joinup' ) . '" type="text" value="' . esc_attr( $qodef_commenter['comment_author_email'] ) . '" size="30" maxlength="100" aria-describedby="email-notes" ' . $qodef_required_attr . ' />
                            <span class="qodef-icon kikol kiko-email"></span></div>',
			    'url'    => '<label for="url" class="qodef-comment-form-label">' .esc_html__('Website', 'joinup'). '</label>
                            <div class="qodef-input-holder">
                            <input id="url" name="url" placeholder="' . esc_attr__( 'Website', 'joinup' ) . '" type="text" value="' . esc_attr( $qodef_commenter['comment_author_url'] ) . '" size="30" maxlength="200" />
                            <span class="qodef-icon kikol kiko-link"></span></div>',
		    ),
		    'submit_button'      => '<button name="%1$s" type="submit" id="%2$s" class="%3$s" value="%4$s"><span class="qodef-m-text">%4$s</span></button>',
		    'class_submit'       => 'qodef-button qodef-layout--filled',
		    'class_form'         => 'qodef-comment-form',
	    );
	    
	    return apply_filters( 'joinup_filter_comment_form_args', $args );
    }
}