<?php
/**
 * Single Event Template
 * A single event. This displays the event title, description, meta, and
 * optionally, the Google map for the event.
 *
 * Override this template in your own theme by creating a file at [your-theme]/tribe-events/single-event.php
 *
 * @package TribeEventsCalendar
 *
 */

if(!defined('ABSPATH')) {
	die('-1');
}

$events_label_singular = tribe_get_event_label_singular();
$events_label_plural   = tribe_get_event_label_plural();

$event_id = get_the_ID();

?>

<div id="tribe-events-content" class="tribe-events-single qodef-tribe-events-single-item qodef-e">
	<!-- Notices -->
	<?php tribe_the_notices() ?>

	<div class="qodef-e-main-info">

        <div class="qodef-e-title-holder">
            <h2 class="qodef-e-title"><?php the_title(); ?></h2>
            <?php if(tribe_get_cost($event_id)) { ?>
                <div class="qodef-e-cost">
                    <?php echo tribe_get_cost(null, true); ?>
                </div>
            <?php } ?>
        </div>

        <div class="qodef-e-info">
            <div class="qodef-e-info-item">
                <?php joinup_render_icon( 'kikol kiko-calendar', 'kiko', '' ); ?>
                <span><?php echo tribe_get_start_date($event_id, false, 'D, M j'); ?></span>
            </div>

            <div class="qodef-e-info-item">
                <?php joinup_render_icon( 'kikol kiko-clock', 'kiko', '' ); ?>
                <span><?php echo tribe_get_start_time(); ?> - <?php echo tribe_get_end_time(); ?></span>
            </div>

            <div class="qodef-e-info-item">
                <?php joinup_render_icon( 'kikol kiko-marker-map', 'kiko', '' ); ?>
                <?php if(tribe_has_venue()) : ?>
                    <span><?php echo tribe_get_venue(); ?></span>
                <?php endif; ?>
            </div>
        </div>
	</div>

	<div class="qodef-e-main-content">

        <div class="qodef-media-holder qodef-grid qodef-layout--template <?php echo joinup_get_grid_gutter_classes(); ?>">
            <div class="qodef-grid-inner clear">
                <div class="qodef-grid-item qodef-col--6">
                    <div class="qodef-e-media">
                        <?php echo tribe_event_featured_image($event_id, 'full', false); ?>
                    </div>
                </div>
                <div class="qodef-grid-item qodef-col--6">
                    <div class="qodef-e-map">
                        <?php tribe_get_template_part('modules/meta/map'); ?>
                    </div>
                </div>
            </div>
		</div>

		<div class="qodef-e-content">
			<?php do_action('tribe_events_single_event_before_the_content') ?>
            <div class="qodef-e-excerpt">
                <?php the_content(); ?>
            </div>
			<?php do_action('tribe_events_single_event_before_the_meta') ?>

            <div class="qodef-e-meta-holder qodef-grid qodef-layout--template <?php echo joinup_get_grid_gutter_classes(); ?>">
                <div class="qodef-grid-inner clear">
                    <div class="qodef-grid-item qodef-col--4">
                        <h4 class="qodef-e-meta-title"><?php esc_html_e('Details:', 'joinup'); ?></h4>
                        <div class="qodef-e-meta-item">
                            <span class="qodef-e-meta-label"><?php esc_html_e('Date:', 'joinup'); ?></span>
                            <span class="qodef-e-meta-value"><?php echo tribe_get_start_date($event_id, false, 'D, M j'); ?></span>
                        </div>
                        <div class="qodef-e-meta-item">
                            <span class="qodef-e-meta-label"><?php esc_html_e('Time:', 'joinup'); ?></span>
                            <span class="qodef-e-meta-value"><?php echo tribe_get_start_time(); ?> - <?php echo tribe_get_end_time(); ?></span>
                        </div>
                        <div class="qodef-e-meta-item">
                            <span class="qodef-e-meta-label"><?php esc_html_e('Cost:', 'joinup'); ?></span>
                            <span class="qodef-e-meta-value"><?php echo tribe_get_cost(null, true); ?></span>
                        </div>
                    </div>

                    <div class="qodef-grid-item qodef-col--4">
                        <h4 class="qodef-e-meta-title"><?php esc_html_e('Organizer:', 'joinup'); ?></h4>
                        <?php if(tribe_has_organizer()) : ?>
                            <div class="qodef-e-meta-item">
                                <span class="qodef-e-meta-label"><?php esc_html_e('Name:', 'joinup'); ?></span>
                                <span class="qodef-e-meta-value"><?php echo tribe_get_organizer(); ?></span>
                            </div>
                        <?php endif; ?>
                        <?php if(tribe_get_organizer_email()) : ?>
                            <div class="qodef-e-meta-item">
                                <span class="qodef-e-meta-label"><?php esc_html_e('Email:', 'joinup'); ?></span>
                                <span class="qodef-e-meta-value">
                                    <a href="mailto: <?php echo tribe_get_organizer_email(); ?>">
                                        <?php echo tribe_get_organizer_email(); ?>
                                    </a>
                                </span>
                            </div>
                        <?php endif; ?>
                        <?php if(tribe_get_organizer_phone()) : ?>
                            <div class="qodef-e-meta-item">
                                <span class="qodef-e-meta-label"><?php esc_html_e('Phone:', 'joinup'); ?></span>
                                <span class="qodef-e-meta-value">
                                    <a href="tel:<?php echo tribe_get_organizer_phone(); ?>">
                                        <?php echo esc_html( tribe_get_organizer_phone() ); ?>
                                    </a>
                                </span>
                            </div>
                        <?php endif; ?>
                        <?php if(tribe_get_organizer_website_link()) : ?>
                            <div class="qodef-e-meta-item">
                                <span class="qodef-e-meta-label"><?php esc_html_e('Website:', 'joinup'); ?></span>
                                <span class="qodef-e-meta-value">
                                    <a target="_blank" href="<?php echo tribe_get_organizer_website_url(); ?>">
                                        <?php echo tribe_get_organizer_website_url(); ?>
                                    </a>
                                </span>
                            </div>
                        <?php endif; ?>
                    </div>
                    <div class="qodef-grid-item qodef-col--4">
                        <h4 class="qodef-e-meta-title"><?php esc_html_e('Venue:', 'joinup'); ?></h4>
                        <?php if(tribe_has_venue()) : ?>
                            <div class="qodef-e-meta-item">
                                <span class="qodef-e-meta-label"><?php esc_html_e('Place:', 'joinup'); ?></span>
                                <span class="qodef-e-meta-value"><?php echo tribe_get_venue(); ?></span>
                            </div>
                        <?php endif; ?>
                        <?php if(tribe_address_exists()) : ?>
                            <div class="qodef-e-meta-item">
                                <span class="qodef-e-meta-label"><?php esc_html_e('Location:', 'joinup'); ?></span>
                                <span class="qodef-e-meta-value">
                                    <a href="https://www.google.com/maps/search/?api=1&query=<?php echo rawurlencode(tribe_get_address()); ?>" target="_blank">
                                        <?php echo tribe_get_address(); ?>
                                    </a>
                                </span>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
            </div>

			<?php do_action('tribe_events_single_event_after_the_meta'); ?>
		</div>

		<?php do_action('tribe_events_single_event_after_the_content') ?>
	</div>

</div>
